@@ -73,7 +73,7 @@ class SimpleAPI(object):
                     m, p = None, None
                 if self.permission(m, p, self.secret_key):
                     runtime = time()
-                    response = self.method()
+                    response = self.method(request)
                     response = json_serialize(response)
                     runtime = round(time() - runtime, 3)
                     response = send_response(status="ok", data=response, runtime=runtime)
@@ -87,7 +87,7 @@ class SimpleAPI(object):
             response = make_callback_function(response, self.get['callback'])
         return response
 
-    def method(self):
+    def method(self, request):
         # it must returns a data
         return None
 
@@ -228,7 +228,7 @@ class ModelAPI(SimpleAPI):
                 setattr(self, attr, BooleanVariable(blank=_blank))
             # ForeinKey and ManyToManyKey ?
 
-    def method(self):
+    def method(self, request):
         if self.action == 'get':
             data = self.get_item()
         elif self.action == 'edit':
